@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 0.10
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.0"))
+;; Version: 1.1
+;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4"))
 ;; Homepage: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, wp
 
@@ -617,7 +617,7 @@ the font.")
              :line-width
              ;; Emacs 28 supports different line horizontal and vertical line widths
              (if (eval-when-compile (>= emacs-major-version 28))
-                 (cons 0 (- border))
+                 (cons -1 (- border))
                (- border)))))))
 
 (defun org-modern--update-fringe-bitmaps ()
@@ -796,8 +796,7 @@ the font.")
     (remove-hook 'pre-redisplay-functions #'org-modern--pre-redisplay 'local)
     (remove-hook 'org-after-promote-entry-hook #'org-modern--unfontify-line 'local)
     (remove-hook 'org-after-demote-entry-hook #'org-modern--unfontify-line 'local)))
-  (save-restriction
-    (widen)
+  (without-restriction
     (with-silent-modifications
       (org-modern--unfontify (point-min) (point-max)))
     (font-lock-flush)))
@@ -810,10 +809,10 @@ the font.")
   "Unfontify prettified elements between BEG and END."
   (let ((font-lock-extra-managed-props
          (append
-          ;; Only remove line-prefix and wrap-prefix if org-indent-mode is disabled.
-          (if (bound-and-true-p org-indent-mode)
-              '(display invisible)
-            '(wrap-prefix line-prefix display invisible))
+          ;; Only remove line/wrap-prefix if block fringes are used
+          (if (and org-modern-block-fringe (not (bound-and-true-p org-indent-mode)))
+              '(wrap-prefix line-prefix display invisible)
+            '(display invisible))
           font-lock-extra-managed-props)))
     (org-unfontify-region beg end)))
 
